# Linguister
[![Build Status](https://travis-ci.org/CoCongV/translator.svg?branch=master)](https://travis-ci.org/CoCongV/translator)
[![codebeat badge](https://codebeat.co/badges/e56760cc-a634-475c-887a-5227a6a696fd)](https://codebeat.co/projects/github-com-cocongv-translator-develop)
[![Maintainability](https://api.codeclimate.com/v1/badges/b0bee8de11cb57a8173d/maintainability)](https://codeclimate.com/github/CoCongV/translator/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/b0bee8de11cb57a8173d/test_coverage)](https://codeclimate.com/github/CoCongV/translator/test_coverage)

Terminal translate tool for linux
---
Support: Chinese, English